.. image:: https://travis-ci.org/Tinche/flattrs.svg?branch=master
   :target: https://travis-ci.org/Tinche/flattrs
   :alt: CI Status

Changelog:
----------

0.1.4 (2019-10-23)
~~~~~~~~~~~~~~~~~~
* Support optional unions.

0.1.3 (2019-06-18)
~~~~~~~~~~~~~~~~~~
* Support lists of int enums.

0.1.2 (2019-01-31)
~~~~~~~~~~~~~~~~~~
* Fixed an issue with unions of tables from another namespace.
* Removed spurious print when serializing byte arrays.

0.1.1 (2018-09-21)
~~~~~~~~~~~~~~~~~~
* Fixed an issue with union classes.